@@ -7,6 +7,7 @@ import json
 import requests
 import botocore.session
 from botocore.awsrequest import create_request_object
+from botocore.config import Config
 from retry import retry
 from cloudutils.vault import Vault
 import json
@@ -16,6 +17,12 @@ log = logging.getLogger(__name__)
 
 class VaultEC2(Vault):
 
+    AWS_CONFIG = Config(
+        retries=dict(
+            max_attempts=10
+        )
+    )
+
     def __init__(self, vault_server, instance_object,  **kwargs):
         self.vault_server = vault_server
         self.token = None
@@ -38,7 +45,7 @@ class VaultEC2(Vault):
         '''
         try:
             session = botocore.session.get_session()
-            client = session.create_client('sts')
+            client = session.create_client('sts', config=self.AWS_CONFIG)
             endpoint = client._endpoint
             operation_model = client._service_model.operation_model('GetCallerIdentity')
             request_dict = client._convert_to_request_dict({}, operation_model)
